@@ -1,6 +1,6 @@
 
 /* Ekiga -- A VoIP and Video-Conferencing application
- * Copyright (C) 2000-2006 Damien Sandras
+ * Copyright (C) 2000-2009 Damien Sandras <dsandras@seconix.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,6 +41,7 @@
 #include "gmconfwidgets.h"
 
 #include <string.h>
+#include <libintl.h>
 
 enum {
   COLUMN_STRING_RAW = 0, /* must be zero because it's used in gmconfwidgets */
@@ -367,7 +368,7 @@ gnome_prefs_spin_new (GtkWidget *table,
   adj = (GtkAdjustment *) 
     gtk_adjustment_new (gm_conf_get_int (conf_key),
 			min, max, step,
-			10.0, 1.0);
+			10.0, 0.0);
   
   spin_button = gtk_spin_button_new (adj, 1.0, 0);
   if (!writable)
@@ -610,7 +611,8 @@ gnome_prefs_string_option_menu_new (GtkWidget *table,
 				    const gchar **options,
 				    const gchar *conf_key,       
 				    const gchar *tooltip,         
-				    int row)       
+				    int row,
+                                    const gchar *default_value)
 {
   GnomePrefsWindow *gpw = NULL;
   
@@ -661,6 +663,8 @@ gnome_prefs_string_option_menu_new (GtkWidget *table,
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), option_menu);
 
   conf_string = gm_conf_get_string (conf_key);
+  if (conf_string == NULL)
+    conf_string = g_strdup (default_value);
   while (options [cpt]) {
 
     if (conf_string && !strcmp (conf_string, options [cpt]))
@@ -718,7 +722,8 @@ gnome_prefs_string_option_menu_new (GtkWidget *table,
 void
 gnome_prefs_string_option_menu_update (GtkWidget *option_menu,
 				       const gchar **options,
-				       const gchar *conf_key)
+				       const gchar *conf_key,
+                                       const gchar *default_value)
 {
   GtkTreeModel *model = NULL;
   GtkTreeIter iter;
@@ -733,6 +738,8 @@ gnome_prefs_string_option_menu_update (GtkWidget *option_menu,
     return;
   
   conf_string = gm_conf_get_string (conf_key);
+  if (conf_string == NULL)
+    conf_string = g_strdup (default_value);
 
   model = gtk_combo_box_get_model (GTK_COMBO_BOX (option_menu));
 
@@ -980,7 +987,10 @@ gnome_prefs_window_new (const gchar *logo_name)
   gtk_container_add (GTK_CONTAINER (event_box),
 		     GTK_WIDGET (pixmap));
 
-  gdk_color_white (gdk_colormap_get_system (), &cwhite); 
+  cwhite.red   = 0xff * 0x100;
+  cwhite.green = 0xff * 0x100;
+  cwhite.blue  = 0xff * 0x100;
+  gdk_colormap_alloc_color(gdk_colormap_get_system (), &cwhite, FALSE, TRUE);
   gtk_widget_modify_bg (GTK_WIDGET (event_box),
 			GTK_STATE_NORMAL, &cwhite);
 
